<?xml version="1.0"?>
<app>

<category>
Graphics
</category>

<name>
Blender
</name>

<description>
   <am>a free and open source 3D animation suite</am>
   <ar>a free and open source 3D animation suite</ar>
   <bg>a free and open source 3D animation suite</bg>
   <ca>Suite d'animació 3D lliure i de codi obert</ca>
   <cs>a free and open source 3D animation suite</cs>
   <da>en fri og open source 3D-animationspakke</da>
   <de>Eine kostenlose und quelloffene 3D-Animationssuite</de>
   <el>μια ελεύθερη σουίτα 3D animation</el>
   <en>a free and open source 3D animation suite</en>
   <es>una suite de animación en 3D libre y de código abierto</es>
   <et>a free and open source 3D animation suite</et>
   <eu>a free and open source 3D animation suite</eu>
   <fa>a free and open source 3D animation suite</fa>
   <fi>a free and open source 3D animation suite</fi>
   <fr>Une suite logicielle libre et open source d'animation 3D</fr>
   <he_IL>a free and open source 3D animation suite</he_IL>
   <hi>a free and open source 3D animation suite</hi>
   <hr>a free and open source 3D animation suite</hr>
   <hu>a free and open source 3D animation suite</hu>
   <id>a free and open source 3D animation suite</id>
   <is>a free and open source 3D animation suite</is>
   <it>Programma gratuito ed open source di animazione 3D</it>
   <ja_JP>a free and open source 3D animation suite</ja_JP>
   <ja>a free and open source 3D animation suite</ja>
   <kk>a free and open source 3D animation suite</kk>
   <ko>a free and open source 3D animation suite</ko>
   <lt>a free and open source 3D animation suite</lt>
   <mk>a free and open source 3D animation suite</mk>
   <nb>a free and open source 3D animation suite</nb>
   <nl>een gratis en open source 3D animatie suite</nl>
   <pl>wolne i otwarte oprogramowanie do modelowania i renderowania obrazów oraz animacji 3D</pl>
   <pt_BR>Conjunto de animação 3D livre e de fonte aberta</pt_BR>
   <pt>Conjunto de animação 3D livre e de fonte aberta</pt>
   <ro>a free and open source 3D animation suite</ro>
   <ru>Бесплатная среда 3D анимации с открытым кодом</ru>
   <sk>a free and open source 3D animation suite</sk>
   <sl>a free and open source 3D animation suite</sl>
   <sq>a free and open source 3D animation suite</sq>
   <sr>a free and open source 3D animation suite</sr>
   <sv>en fri och öppen källkods 3D animationssvit</sv>
   <tr>a free and open source 3D animation suite</tr>
   <uk>вільний та відкритий пакет для роботи з 3D графікою</uk>
   <zh_CN>a free and open source 3D animation suite</zh_CN>
   <zh_TW>a free and open source 3D animation suite</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>https://screenshots.debian.net/screenshots/000/012/359/large.png</screenshot>

<preinstall>

</preinstall>

<install_package_names>
blender
libgl1-mesa-dri
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
blender
libgl1-mesa-dri
</uninstall_package_names>
</app>
